Improve this Doc View Source

Specify custom behavior on copy event.

## Directive Info

- This directive executes at priority level 0.

## Usage

- as element:

      <ng-copy
        ng-copy="expression">
      ...
      </ng-copy>

- as attribute:

      <window, input, select, textarea, a
        ng-copy="expression">
      ...
      </window, input, select, textarea, a>

### Arguments

Param | Type | Details
--- | --- | ---
ngCopy | expression | Expression to evaluate upon copy. (Event object is available as `$event`)

## Examples

    <input ng-copy="copied=true" ng-init="copied=false; value='copy me'" ng-model="value">
    copied: {{copied}}